summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/Makefile.am2
-rw-r--r--src/kvpnc.cpp6
-rw-r--r--src/kvpncconfig.cpp8
-rw-r--r--src/kvpncconfig.h4
4 files changed, 10 insertions, 10 deletions
diff --git a/src/Makefile.am b/src/Makefile.am
index 9101baa..230a086 100644
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -49,7 +49,7 @@ kvpnc_METASOURCES = AUTO
#CXXFLAGS = $(libgcrypt-config --libs --cflags)
-kvpnc_LDADD = $(LIB_KFILE) $(LIB_TDEUI) $(LIB_TDECORE) $(LIB_QT) $(LIBSOCKET) -lgcrypt -lkwalletclient -lDCOP
+kvpnc_LDADD = $(LIB_KFILE) $(LIB_TDEUI) $(LIB_TDECORE) $(LIB_QT) $(LIBSOCKET) -lgcrypt -ltdewalletclient -lDCOP
diff --git a/src/kvpncconfig.cpp b/src/kvpncconfig.cpp
index 523aae7..12b2b09 100644
--- a/src/kvpncconfig.cpp
+++ b/src/kvpncconfig.cpp
@@ -432,7 +432,7 @@ void KVpncConfig::saveOptions(bool saveOneProfile, TQString Profile)
VpnAccountData *it;
if ( !AccountList->isEmpty() )
{
- /* passwords with kwallet */
+ /* passwords with tdewallet */
if ( useKwallet && KWallet::Wallet::isEnabled())
{
if (!skipKwalletStoring )
@@ -487,7 +487,7 @@ void KVpncConfig::saveOptions(bool saveOneProfile, TQString Profile)
config->writeEntry("Description",it->getDescription());
- /* passwords with kwallet */
+ /* passwords with tdewallet */
if ( useKwallet && KWallet::Wallet::isEnabled())
{
if (!skipKwalletStoring )
@@ -1095,7 +1095,7 @@ void KVpncConfig::loadOptions()
TQString PrivateKeyPass="";
TQString PreSharedKey ="";
- /* passwords with kwallet */
+ /* passwords with tdewallet */
if (useKwallet && KWallet::Wallet::isEnabled())
{
if (KvpncDebugLevel > 2)
@@ -4362,7 +4362,7 @@ void KVpncConfig::removeEntry(TQString Name)
ProfileName += name;
config->setGroup( ProfileName );
- /* passwords with kwallet */
+ /* passwords with tdewallet */
if ( useKwallet && KWallet::Wallet::isEnabled())
{
// if (KvpncDebugLevel > 0)
diff --git a/src/kvpncconfig.h b/src/kvpncconfig.h
index ad83b8b..3d52d9d 100644
--- a/src/kvpncconfig.h
+++ b/src/kvpncconfig.h
@@ -34,7 +34,7 @@
#include <tqcolor.h>
#include <tqstringlist.h>
#include <kconfig.h>
-#include <kwallet.h>
+#include <tdewallet.h>
#include <kstatusbar.h>
#include "toolinfo.h"
@@ -146,7 +146,7 @@ public:
bool firstUseOfKwallet; //< for importing passwords if there are stored before
bool shutdownIsCalled;
bool haveUserData; //< flag if user data already collected, set after data is entered and unset if authretry
- bool skipKwalletStoring; //< true if save should skip saving into kwallet
+ bool skipKwalletStoring; //< true if save should skip saving into tdewallet
bool hideOnCloseInfo;
bool feedbackMailSent;
bool doKillL2tpdIfStillRunning; //< kill l2tpd if its still running and not started from kvpnc
diff --git a/src/kvpnc.cpp b/src/kvpnc.cpp
index d00f945..4524d26 100644
--- a/src/kvpnc.cpp
+++ b/src/kvpnc.cpp
@@ -81,7 +81,7 @@
#include <kglobal.h>
#include <kstandarddirs.h>
#include <knuminput.h>
-#include <kwallet.h>
+#include <tdewallet.h>
#include <kinputdialog.h>
#include <kactioncollection.h>
#include <kfiledialog.h>
@@ -838,7 +838,7 @@ void KVpnc::closeEvent ( TQCloseEvent *e )
if ( GlobalConfig->status == GlobalConfig->connected )
{
int res;
- if ( kapp->sessionSaving() ) //KDE is going down, skip kwallet, disconnect and quit
+ if ( kapp->sessionSaving() ) //KDE is going down, skip tdewallet, disconnect and quit
{
if ( GlobalConfig->KvpncDebugLevel > 0 )
GlobalConfig->appendLogEntry ( i18n ( "Shutdown was called...exiting.\n" ), GlobalConfig->debug );
@@ -11224,7 +11224,7 @@ void KVpnc::helpClicked()
//
// KMessageBox::information(0,extip,"ext ip" );
// /* passwords with kwallet */
// if (GlobalConfig->useKwallet && KWallet::Wallet::isEnabled())
// {
// // Open local wallet
@@ -11224,7 +11224,7 @@ void KVpnc::helpClicked()
//
// KMessageBox::information(0,extip,"ext ip" );
- // /* passwords with kwallet */
+ // /* passwords with tdewallet */
// if (GlobalConfig->useKwallet && KWallet::Wallet::isEnabled())
// {